@@ -11,11 +11,11 @@ JIRA::Client - An extended interface to JIRA's SOAP API.
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 SYNOPSIS
 
@@ -139,7 +139,16 @@ sub new {
 }
 
 sub DESTROY {
-    shift->logout();
+    # FIXME - This call to logout during global destruction in the
+    # context of the SVN::Hooks module doesn't work right. When it's
+    # called the 'soap' member is undefined for a reason that escapes
+    # me so far. Getting rid of the DESTROY method doesn't work either
+    # because it would trigger a call to AUTOLOAD which is unable to
+    # do it correctly. I think a call to logout is proper here to shut
+    # down the SOAP connection cleanly, but it doesn't seems to hurt
+    # to not call it.
+
+    # shift->logout();
 }
 
 =item B<create_issue> HASH_REF
